"""
SatZoomer
=========

Provides
    1. Tools to add a new country / satellite specification
    2. Tools to extract the normalized and colour-balanced RGB / IRG tiles from the raw panchromatic mosaic
    3. Tools to combine spectral indices with deep learning heatmaps to produce land cover maps

Available subpackages
---------------------
spectral_indices
    Tools to extract known spectral indices from multispectral data (e.g. NDVI / NDWI)

utils
    Tools to visualize outputs and reduce radiometric depth
"""

__version__ = '1.0.0'